@@ -6,7 +6,7 @@ import textwrap as tr
 import sys
 import logging
 from sylo.models import Durations, Config
-from sylo.utils import get_today, get_weekday
+from sylo.utils import get_today, get_weekday, strike
 
 
 logger = logging.getLogger(__name__)
@@ -36,18 +36,24 @@ class Display:
     def print_timer(self, mode: str, timer_val: int, tasks: List = None):
         if mode == "work":
             self.print_header_small()
+            print(
+                self.col(f"Tasks for {calendar.day_name[get_weekday()]} {get_today()}")
+            )
+            print(self.col("-----------------------------------------"))
             self.print_tasks(tasks)
             print(
-                f"{self.col('Press')} {self.col('Ctrl-C', 'yellow')} "
+                f"\n{self.col('Press')} {self.col('Ctrl-C', 'yellow')} "
                 f"{self.col('to stop timer early.')}"
                 "\n"
                 f"\n{self.col('WORK', 'red')} "
-                f"for {self.col(str(timer_val), 'yellow')} minutes"
+                f"{self.col('for')} {self.col(str(timer_val), 'yellow')} {self.col('minutes')}"
             )
         else:
             self.print_header_small()
+            print(self.col(f"{calendar.day_name[get_weekday()]} {get_today()}"))
             print(
-                f"Ctrl-C to stop timer early."
+                f"\n{self.col('Press')} {self.col('Ctrl-C', 'yellow')} "
+                f"{self.col('to stop timer early.')}"
                 f"\n{self.col('REST', 'green')} "
                 f"for {self.col(str(timer_val), 'yellow')} minutes"
             )
@@ -62,9 +68,11 @@ class Display:
 
     def print_insights(self, durations: Durations):
         print(
-            f"\nTotal {self.col('work', 'red')} today:           "
+            f"\nTotal {self.col(self.add_plurality(self.pom_name), 'lmagenta')} today:          "
+            f"{self.col(str(int(durations.poms)), 'yellow')} {self.add_plurality(self.pom_name)}"
+            f"\nTotal {self.col('Work', 'red')} today:           "
             f"{self.col(str(int(durations.total_work_mins)), 'yellow')} minutes"
-            f"\nTotal {self.col('rest', 'green')} today:           "
+            f"\nTotal {self.col('Rest', 'green')} today:           "
             f"{self.col(str(int(durations.total_rest_mins)), 'yellow')} minutes\n"
             f"\n{self.col('Press')} "
             f"{self.col('ENTER', 'yellow')} "
@@ -93,7 +101,7 @@ class Display:
 
     def print_splash_prompt(self):
         print(
-            f"{self.col('Press')} "
+            f"\n{self.col('Press')} "
             f"{self.col('ENTER', 'yellow')} "
             f"{self.col('to start the next timer.')}"
         )
@@ -102,6 +110,7 @@ class Display:
         print(f"{self.col('Press')} {self.col('H', 'yellow')} {self.col('for Help.')}")
 
     def print_add_task_or_quit(self):
+        print("\n")
         print(
             f"{self.col('Press')} "
             f"{self.col('ENTER', 'yellow')} "
@@ -117,12 +126,15 @@ class Display:
         )
 
     def print_new_task(self):
+        print("\n")
         print(f"{self.col('Input a new task')}")
 
     def print_edit_task(self):
+        print("\n")
         print(f"{self.col('Pick a task to complete/put back')}")
 
     def print_remove_task(self):
+        print("\n")
         print(f"{self.col('Pick a task to DELETE')}")
 
     def fix_indent(self):
@@ -132,15 +144,17 @@ class Display:
             fix_str += " "
         return fix_str
 
-    def print_splash(self, durations: Durations, mode: str):
-        print(self.col(f"{calendar.day_name[get_weekday()]} {get_today()}"))
-        print(self.col("-----------------------------------------\n"))
+    def print_splash(self, durations: Durations, mode: str, tasks: List):
         print(
-            f"Total {self.add_plurality(self.pom_name)} today:{self.fix_indent()}      "
-            f"{self.print_poms(int(durations.poms))}"
-            f"\nUpcoming timer:     "
-            f"        {self.col(mode.upper(), self._set_mode_color(mode, durations))}"
-            f"\n"
+            self.col(
+                f"Tasks for today, {calendar.day_name[get_weekday()]} {get_today()}"
+            )
+        )
+        print(self.col("-----------------------------------------"))
+        self.print_tasks(tasks)
+        print(
+            f"\n{self.col('Upcoming timer: ')}"
+            f"{self.col(mode.upper(), self._set_mode_color(mode, durations))}  "
         )
 
     def print_splash_variants(
@@ -153,7 +167,7 @@ class Display:
     ):
         logger.info(f"Splash. is_options: {is_options} is_tasks: {is_tasks}")
         self.print_header_small()
-        self.print_splash(durations, mode)
+        self.print_splash(durations, mode, tasks)
         if is_options is True and is_tasks is False:
             self.print_options()
             self.print_splash_prompt()
@@ -170,61 +184,80 @@ class Display:
             self.print_offer_options()
 
     def print_tasks(self, tasks: List = None):
-        if tasks:
-            print(f'{self.col(f"Completed tasks")}\n')
-            print(
-                "\n".join(
-                    "".join(map(str, f"{self.trim_string(self.col(t[2],'green'),45)}"))
-                    for t in tasks
-                    if t[4] == True
+        complete_tasks = "\n".join(
+            "".join(
+                map(
+                    str,
+                    f"{self.col('--')} "
+                    f"{self.print_poms(t[3])}: "
+                    f"{self.trim_string(self.col(strike(t[2]),'green'),65)}",
                 )
             )
-            print("\n")
-            print(f'{self.col(f"Incomplete tasks")}')
-            print(
-                "\n".join(
-                    "".join(
-                        map(str, f"\n{self.print_poms(t[3])}: " f"{tr.fill(t[2], 45)}")
-                    )
-                    for t in tasks
-                    if t[4] == False
+            for t in tasks
+            if t[4] == True
+        )
+        incomplete_tasks = "\n".join(
+            "".join(
+                map(
+                    str,
+                    f"{self.col('--')} "
+                    f"{self.print_poms(t[3])}: "
+                    f"{tr.fill(t[2], 45)}",
                 )
             )
-            print("\n")
+            for t in tasks
+            if t[4] == False
+        )
+        if complete_tasks:
+            print(complete_tasks)
+        if incomplete_tasks:
+            print(incomplete_tasks)
+
+    def print_incomplete_tasks(self, tasks: List = None):
+        incomplete_tasks = "\n".join(
+            "".join(
+                map(
+                    str,
+                    f"{self.col('--')} "
+                    f"{self.print_poms(t[3])}: "
+                    f"{tr.fill(t[2], 45)}",
+                )
+            )
+            for t in tasks
+            if t[4] == False
+        )
+        if incomplete_tasks:
+            print(incomplete_tasks)
 
     def print_tasks_with_id(self, tasks: List = None):
-        if tasks:
-            print(f'{self.col(f"Completed tasks")}\n')
-            print(
-                "\n".join(
-                    "".join(
-                        map(
-                            str,
-                            f"{self.col(t[0], 'yellow')}  "
-                            f"{self.trim_string(self.col(t[2],'green'),45)}",
-                        )
-                    )
-                    for t in tasks
-                    if t[4] == True
+        complete_tasks = "\n".join(
+            "".join(
+                map(
+                    str,
+                    f"{self.col('--')} {self.col(t[0], 'yellow')}  "
+                    f"{self.print_poms(t[3])}: "
+                    f"{self.trim_string(self.col(strike(t[2]),'green'),65)}",
                 )
             )
-            print("\n")
-            print(f'{self.col(f"Incomplete tasks")}\n')
-            print(
-                "\n".join(
-                    "".join(
-                        map(
-                            str,
-                            f"{self.col(t[0], 'yellow')}  "
-                            f"{self.print_poms(t[3])}: "
-                            f"{tr.fill(t[2], 45)}\n",
-                        )
-                    )
-                    for t in tasks
-                    if t[4] == False
+            for t in tasks
+            if t[4] == True
+        )
+        incomplete_tasks = "\n".join(
+            "".join(
+                map(
+                    str,
+                    f"{self.col('--')} {self.col(t[0], 'yellow')}  "
+                    f"{self.print_poms(t[3])}: "
+                    f"{tr.fill(t[2], 45)}",
                 )
             )
-            print("\n")
+            for t in tasks
+            if t[4] == False
+        )
+        if complete_tasks:
+            print(complete_tasks)
+        if incomplete_tasks:
+            print(incomplete_tasks)
 
     def print_header_small(self):
         print(self.col(self.ascii_header(string="SYLO", font="alligator", width=60)))
@@ -269,4 +302,4 @@ class Display:
 
     @staticmethod
     def trim_string(string: str, max_len: int) -> str:
-        return (string[:max_len] + "..") if len(string) > max_len else string
+        return string[:max_len] + ".." if len(string) > max_len else string
