@@ -2,11 +2,10 @@ import logging
 from dataclasses import dataclass
 from sylo.definitions import (
     TIMER_DEFAULTS,
-    TODAY_STR,
     CONFIG_FILE_LOCATION,
     SQLITE_DB,
 )
-from sylo.utils import check_for_file, mins_to_secs
+from sylo.utils import check_for_file, mins_to_secs, get_today
 import tomli
 import sqlite3
 
@@ -143,10 +142,12 @@ class Database:
 
     def initial_data_load(self, durations: Durations):
         (session_data,) = (
-            self.select(f"SELECT * FROM sessions where session_date = '{TODAY_STR}';"),
+            self.select(
+                f"SELECT * FROM sessions where session_date = '{get_today()}';"
+            ),
         )
         (poms_data,) = (
-            self.select(f"SELECT * FROM poms where poms_date = '{TODAY_STR}';"),
+            self.select(f"SELECT * FROM poms where poms_date = '{get_today()}';"),
         )
         try:
             logger.info(session_data)
