@@ -12,6 +12,7 @@ from time import sleep
 from sylo.models import (
     Durations,
     Database,
+    Config,
     ConfigFile,
 )
 from sylo.definitions import (
@@ -50,8 +51,11 @@ initial_boot_flag = False
 
 
 class Timer:
-    def __init__(self, mode: str, durations: Durations, increments: int):
+    def __init__(
+        self, mode: str, durations: Durations, increments: int, config: Config
+    ):
         self.durations = durations
+        self.config = config
         self.mode: str = mode
         self.increments = increments
         self.mins_passed = 0
@@ -82,8 +86,15 @@ class Timer:
             leave=False,
             desc=display.print_timer(self.mode, self.mins, self.tasks),
             unit=" seconds",
-            bar_format="{l_bar}%s{bar}%s{r_bar}"
-            % (display.color_map(self.bar_color), Fore.RESET),
+            bar_format="%s{l_bar}%s%s{bar}%s%s{r_bar}%s"
+            % (
+                display.color_map(self.config.theme_color),
+                Fore.RESET,
+                display.color_map(self.bar_color),
+                Fore.RESET,
+                display.color_map(self.config.theme_color),
+                Fore.RESET,
+            ),
             smoothing=True,
             ncols=70,
         )
@@ -229,6 +240,7 @@ class Sylo:
         tasks: List = None,
         tasks_date: str = None,
         speed_mode: bool = is_speed_mode,
+        config: Config = None,
     ):
         self.durations = durations
         self.sound_obj = sound_obj
@@ -239,6 +251,7 @@ class Sylo:
         self.tasks_date = tasks_date
         self.speed_mode = speed_mode
         self.increments = 1
+        self.config = config
 
     def on_boot(self):
         clear_screen()
@@ -259,9 +272,7 @@ class Sylo:
 
     def show_task(self, dates, with_id: bool = False):
         for date in dates:
-            print("\n")
-            print(display.col(date))
-            print(display.col("-----------------------------------------\n"))
+            print(display.col(f"---------------------------- {date}"))
             self.tasks = database.select(
                 f"SELECT"
                 f'"id",'
@@ -273,13 +284,13 @@ class Sylo:
                 f";"
             )
             if with_id is False:
-                display.print_tasks(self.tasks)
+                display.print_incomplete_tasks(self.tasks)
             else:
                 display.print_tasks_with_id(self.tasks)
             logger.info(f"Tasks: {self.tasks}")
-        return [i[0] for i in self.tasks]
 
-    def task_menu_new(self, dates: List, task: Task):
+    def task_menu_new(self, dates: List):
+        task = Task()
         display.print_new_task()
         task.description = input(display.col("Description >> ", "yellow"))
         task.effort = input(
@@ -290,20 +301,20 @@ class Sylo:
         )
         while task.effort.isnumeric() is False:
             print(display.col("MUST BE NUMERIC", "red"))
-            sleep(2)
+            sleep(1)
             self.task_menu(dates)
         task.write_task_to_db()
         self.task_menu(dates)
 
-    def task_menu_close(self, dates: List):
+    def task_menu_close(self, dates: List, task_ids: List[tuple]):
         clear_screen()
         display.print_header_small()
-        task_ids = self.show_task(dates, True)
+        self.show_task(dates, True)
         display.print_edit_task()
         comp_input = input(display.col("Task id >> ", "yellow"))
         while valid_input(comp_input, task_ids) is False:
             print(display.col("NOT A VALID ID", "red"))
-            sleep(2)
+            sleep(1)
             self.task_menu(dates)
         database.execute(
             f'UPDATE tasks SET "complete" = '
@@ -312,15 +323,15 @@ class Sylo:
         )
         self.task_menu(dates)
 
-    def task_menu_move(self, dates: List):
+    def task_menu_move(self, dates: List, task_ids: List[tuple]):
         clear_screen()
         display.print_header_small()
-        task_ids = self.show_task(dates, True)
+        self.show_task(dates, True)
         display.print_edit_task()
         comp_input = input(display.col("Task id >> ", "yellow"))
         while valid_input(comp_input, task_ids) is False:
             print(display.col("NOT A VALID ID", "red"))
-            sleep(2)
+            sleep(1)
             self.task_menu(dates)
         database.execute(
             f"UPDATE tasks SET \"task_date\" = '{get_today()}'"
@@ -328,22 +339,33 @@ class Sylo:
         )
         self.task_menu(dates)
 
-    def task_menu_delete(self, dates: List):
+    def task_menu_delete(self, dates: List, task_ids: List[tuple]):
         clear_screen()
         display.print_header_small()
-        task_ids = self.show_task(dates, True)
+        self.show_task(dates, True)
         display.print_remove_task()
         comp_input = input(display.col("Task id >> ", "yellow"))
         while valid_input(comp_input, task_ids) is False:
             print(display.col("NOT A VALID ID", "red"))
-            sleep(2)
+            sleep(1)
             self.task_menu(dates)
         database.execute(f"DELETE FROM tasks" f' WHERE "id" = {comp_input};')
         self.task_menu(dates)
 
     def task_menu(self, dates: List):
         clear_screen()
-        task = Task()
+        all_tasks = self.tasks = database.select(
+            f"SELECT"
+            f'"id",'
+            f'"task_date",'
+            f'"description",'
+            f'"effort",'
+            f'"complete"'
+            f'FROM tasks WHERE "task_date" '
+            f">= (SELECT DATETIME({(get_today())}, '-7 day'))"
+            f";"
+        )
+        all_task_ids = [i[0] for i in all_tasks]
         display.print_header_small()
         self.show_task(dates)
         display.print_add_task_or_quit()
@@ -353,13 +375,13 @@ class Sylo:
         if usr_input == "":
             self.home_loop()
         while usr_input.lower() == "n":
-            self.task_menu_new(dates, task)
+            self.task_menu_new(dates)
         while usr_input.lower() == "c":
-            self.task_menu_close(dates)
+            self.task_menu_close(dates, all_task_ids)
         while usr_input.lower() == "m":
-            self.task_menu_move(dates)
+            self.task_menu_move(dates, all_task_ids)
         while usr_input.lower() == "d":
-            self.task_menu_delete(dates)
+            self.task_menu_delete(dates, all_task_ids)
 
     def switch_modes(self):
         logger.info("Switch requested")
@@ -441,7 +463,12 @@ class Sylo:
 
     def home_loop(self):
         self.on_boot()
-        timer = Timer(self.mode, self.durations, self.increments)
+        timer = Timer(
+            mode=self.mode,
+            durations=self.durations,
+            config=self.config,
+            increments=self.increments,
+        )
         self.splash(timer)
         response = get_input(cursor)
         logger.info(f"User response: {response}")
@@ -520,5 +547,17 @@ def run(args, config):
         sound_obj=sound,
         mode=timer_mode,
         speed_mode=is_speed_mode,
+        tasks=database.select(
+            f"SELECT"
+            f'"id",'
+            f'"task_date",'
+            f'"description",'
+            f'"effort",'
+            f'"complete"'
+            f"FROM tasks "
+            f"WHERE \"task_date\" = '{get_today()}'"
+            f";"
+        ),
+        config=config,
     )
     sylo.home_loop()
